@@ -10,6 +10,12 @@ import tempfile
 # to the implementation to decide.
 DB_CONNECTION = os.getenv('DB_CONNECTION')
 
+#: The deployment environment.
+DEPLOYMENT_ENV = os.getenv('DEPLOYMENT_ENV')
+
+#: Directory holding application configuration files.
+ETCDIR = os.path.abspath(os.getenv('APP_ETCDIR') or 'etc/')
+
 RUNDIR = os.getenv('APP_RUNDIR', '/opt/app')
 
 LIBDIR = os.getenv('APP_LIBDIR',
